#!/bin/sh
# description: Starts and stops the webfocus.

WF_USER=webfocus
CUR_DIR=$(cd $(dirname ${0});pwd)
WF_HOME=`dirname ${CUR_DIR}`
BASE_DIR=${WF_HOME}/tools
LOG_DIR=${BASE_DIR}/logs
LOGFILE=${LOG_DIR}/wf_ctrl.log
IBI_HOME=${WF_HOME}/ibi
SRV_HOME=${IBI_HOME}/srv90
CL_HOME=${IBI_HOME}/WebFOCUS90
EDA_BIN=${SRV_HOME}/home/bin
EDA_START=${SRV_HOME}/wfs/bin/edastart
EDAP=${EDABIN}/edap
FDS=${EDABIN}/fds.out
TSCOM=${EDABIN}/tscom3.out
JSCOM=${EDABIN}/jscom3c.out
DERBY_HOME=${IBI_HOME}/derby
DERBY_PORT=1527
TOMCAT_HOME=${IBI_HOME}/tomcat
CASTER_HOME=${CL_HOME}/ReportCaster
SOLR_HOME=${CL_HOME}/Solr
WFMAIN=${BASE_DIR}/wfmain
PIDFILE=${LOG_DIR}/wfmain.pid
DERBY_STARTUP=0
TOMCAT_STARTUP=1
CASTER_STARTUP=1
SOLR_STARTUP=1
MAX_CNT=60
LOGLIMIT=10
RTN=0
umask 000
LOGLIMIT=`expr ${LOGLIMIT} \* 1024`
LOGLIMIT=`expr ${LOGLIMIT} \* 1024`
BOOTWAIT=0

test -f ${HOME}/.bash_profile && source ${HOME}/.bash_profile >/dev/null 2>&1

### check run user
if [ `id -un` != ${WF_USER} ]; then
    echo $"Usage: differences execution user." | tee -a ${LOGFILE}
    exit 1
fi

### change directory
cd ${CUR_DIR}

### check logfile size
mkdir -p ${LOG_DIR}
if [ -f "${LOGFILE}" ]; then
    if [ `ls -l "${LOGFILE}" | awk '{print $5}'` -gt ${LOGLIMIT} ]; then
        rm -f ${LOGFILE}.old >/dev/null 2>&1
        mv ${LOGFILE} ${LOGFILE}.old >/dev/null 2>&1
    fi
fi

### check runmode
RUN=${2}
case ${RUN} in
    "derby")
        RUNDERBY=1
        ;;
    "eda")
        RUNEDA=1
        ;;
    "tomcat")
        RUNTOMCAT=1
        ;;
    "caster")
        RUNCASTER=1
        ;;
    "solr")
        RUNSOLR=1
        ;;
    "")
        RUNDERBY=${DERBY_STARTUP}
        RUNEDA=1
        RUNTOMCAT=${TOMCAT_STARTUP}
        RUNCASTER=${CASTER_STARTUP}
        RUNSOLR=${SOLR_STARTUP}
        ;;
    *)
        echo $"Usage: $0 {start|stop|restart|status} [{derby|eda|tomcat|caster|solr}]" | tee -a ${LOGFILE}
        exit 1
        ;;
esac

CREATE_MAINPID () {
    P_PID=`ps h -o ppid -p ${$}`
    P_PNAME=`ps h -o cmd -p ${P_PID} | awk '{print $1}'`
    if [ "${P_PNAME}" = "/usr/lib/systemd/systemd" ]; then
        test -f ${PIDFILE} && cat ${PIDFILE} | xargs kill -TERM 2>/dev/null && rm -f ${PIDFILE}
        nohup ${WFMAIN} >/dev/null 2>&1 &
        echo ${!} >${PIDFILE}
    fi
}

TERM_MAINPID() {
    P_PID=`ps h -o ppid -p ${$}`
    P_PNAME=`ps h -o cmd -p ${P_PID} | awk '{print $1}'`
    if [ "${P_PNAME}" = "/usr/lib/systemd/systemd" ]; then
        test -f ${PIDFILE} && cat ${PIDFILE} | xargs kill -TERM 2>/dev/null && rm -f ${PIDFILE}
    fi
}

CHK_DERBYSTART() {
    CNT=0
    while [ `ps -ef | grep "derby.system.home=${DERBY_HOME}" | grep -v "grep" | \
            wc -l` -eq 0 -a `netstat -an | grep ":${DERBY_PORT}*LISTEN$" | wc -l` -eq 0 ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby not started [timeout ${CNT} sec]." | \
                    tee -a ${LOGFILE}
            RTN=1
            break
        fi
    done
}

CHK_DERBYSTOP() {
    CNT=0
    while [ `ps -ef | grep "derby.system.home=${DERBY_HOME}" | grep -v "grep" | \
            wc -l` -ne 0 -o `netstat -an | grep ":${DERBY_PORT}*LISTEN$" | wc -l` -ne 0 ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby not stopped [timeout ${CNT} sec]." | \
                tee -a ${LOGFILE}
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby send SIGTERM." | tee -a ${LOGFILE}
            PID=`ps -ef | grep "derby.system.home=${DERBY_HOME}" | \
                    grep -v "grep" | awk '{print $2}'`
            kill -TERM ${PID} >>${LOGFILE} 2>&1
            sleep 1
            if [ `ps -ef | grep "derby.system.home=${DERBY_HOME}" | grep -v "grep" | \
                awk '{print $2}' | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby send SIGKILL." | tee -a ${LOGFILE}
                PID=`ps -ef | grep "derby.system.home=${DERBY_HOME}" | grep -v "grep" | \
                        awk '{print $2}'`
                kill -KILL ${PID} >>${LOGFILE} 2>&1
            fi
            RTN=1
            break
        fi
    done
}

CHK_EDASTART() {
    CNT=0
    while [ `ps -ef | egrep "${EDAP}|${FDS}|${TSCOM}|${JSCOM}" | grep -v "grep" | wc -l` -eq 0 \
            -o `${EDA_START} -status | grep "NotRunning" | wc -l` -ne 0 ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  eda not started [timeout ${CNT} sec]." | \
                    tee -a ${LOGFILE}
            RTN=1
            break
        fi
    done
}

CHK_EDASTOP() {
    CNT=0
    while [ `ps -ef | egrep "${EDAP}|${FDS}|${TSCOM}|${JSCOM}" | grep -v "grep" | wc -l` -ne 0 \
            -o `${EDA_START} -status | grep "NotRunning" | wc -l` -eq 0 ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  eda not stopped [timeout ${CNT} sec]." | \
                    tee -a ${LOGFILE}
            RTN=1
            break
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  eda send SIGTERM." | tee -a ${LOGFILE}
            PID=`ps -ef | egrep "${EDAP}|${FDS}|${TSCOM}|${JSCOM}" | \
                    grep -v "grep" | awk '{print $2}'`
            kill -TERM ${PID} >>${LOGFILE} 2>&1
            sleep 1
            if [ `ps -ef | egrep "${EDAP}|${FDS}|${TSCOM}|${JSCOM}" | grep -v "grep" | \
                awk '{print $2}' | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  eda send SIGKILL." | tee -a ${LOGFILE}
                PID=`ps -ef | egrep "${EDAP}|${FDS}|${TSCOM}|${JSCOM}" | grep -v "grep" | \
                        awk '{print $2}'`
                kill -KILL ${PID} >>${LOGFILE} 2>&1
            fi
        fi
    done
}

CHK_TOMCATSTART() {
    CNT=0
    while [ `ps -ef | grep "${TOMCAT_HOME}" | grep -v "grep" | wc -l` -eq 0 \
            ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  tomcat not started [timeout ${CNT} sec]." | \
                    tee -a ${LOGFILE}
            RTN=1
            break
        fi
    done
}

CHK_TOMCATSTOP() {
    CNT=0
    while [ `ps -ef | grep "${TOMCAT_HOME}" | grep -v "grep" | wc -l` -ne 0 \
            ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  tomcat not stopped [timeout ${CNT} sec]." | \
                    tee -a ${LOGFILE}
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  tomcat send SIGTERM." | tee -a ${LOGFILE}
            PID=`ps -ef | grep "${TOMCAT_HOME}" | grep -v "grep" | awk '{print $2}'`
            kill -TERM ${PID} >>${LOGFILE} 2>&1
            sleep 1
            if [ `ps -ef | grep "${TOMCAT_HOME}" | grep -v "grep" | awk '{print $2}' | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  tomcat send SIGKILL." | tee -a ${LOGFILE}
                PID=`ps -ef | grep "${TOMCAT_HOME}" | grep -v "grep" | awk '{print $2}'`
                kill -KILL ${PID} >>${LOGFILE} 2>&1
            fi
            RTN=1
            break
        fi
    done
}

CHK_CASTERSTART() {
    CNT=0
    while [ `ps -ef | grep "${CASTER_HOME}" | grep -v "grep" | wc -l` -eq 0 ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby not started [timeout ${CNT} sec]." | \
                    tee -a ${LOGFILE}
            RTN=1
            break
        fi
    done
}

CHK_CASTERSTOP() {
    CNT=0
    while [ `ps -ef | grep "${CASTER_HOME}" | grep -v "grep" | wc -l` -ne 0 ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  caster not stopped [timeout ${CNT} sec]." | \
                    tee -a ${LOGFILE}
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  caster send SIGTERM." | \
                    tee -a ${LOGFILE}
            PID=`ps -ef | grep "${CASTER_HOME}" | \
                 grep -v "grep" | awk '{print $2}'`
            kill -TERM ${PID} >>${LOGFILE} 2>&1
            sleep 1
            if [ `ps -ef | grep "${CASTER_HOME}" | grep -v "grep" | awk '{print $2}' | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  caster send SIGKILL." | tee -a ${LOGFILE}
                PID=`ps -ef | grep "${CASTER_HOME}" | grep -v "grep" | awk '{print $2}'`
                kill -KILL ${PID} >>${LOGFILE} 2>&1
            fi
            RTN=1
            break
        fi
    done
}

CHK_SOLRSTART() {
    CNT=0
    while [ `ps -ef | grep "${SOLR_HOME}" | grep -v "grep" | wc -l` -eq 0 \
            ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  solr not started [timeout ${CNT} sec]." | \
                    tee -a ${LOGFILE}
            RTN=1
            break
        fi
    done
}

CHK_SOLRSTOP() {
    CNT=0
    while [ `ps -ef | grep "${SOLR_HOME}" | grep -v "grep" | wc -l` -ne 0 \
            ]; do
        sleep 1
        CNT=`expr ${CNT} + 1`
        if [ ${CNT} -ge ${MAX_CNT} ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  solr not stopped [timeout ${CNT} sec]." | \
                    tee -a ${LOGFILE}
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  solr send SIGTERM." | tee -a ${LOGFILE}
            PID=`ps -ef | grep "${SOLR_HOME}" | grep -v "grep" | awk '{print $2}'`
            kill -TERM ${PID} >>${LOGFILE} 2>&1
            sleep 1
            if [ `ps -ef | grep "${SOLR_HOME}" | grep -v "grep" | awk '{print $2}' | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  solr send SIGKILL." | tee -a ${LOGFILE}
                PID=`ps -ef | grep "${SOLR_HOME}" | grep -v "grep" | awk '{print $2}'`
                kill -KILL ${PID} >>${LOGFILE} 2>&1
            fi
            RTN=1
            break
        fi
    done
}

### boot wait
P_PID=`ps h -o ppid -p ${$}`
P_PNAME=`ps h -o cmd -p ${P_PID} | awk '{print $1}'`
if [ "${P_PNAME}" = "/usr/lib/systemd/systemd" ]; then
    echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  sleep ${BOOTWAIT} seconds." | tee -a ${LOGFILE}
    sleep ${BOOTWAIT}
fi

case "${1}" in
    start)
        ### solr start
        if [ -f "${SOLR_HOME}/start_solr_linux.sh" -a "${RUNSOLR}" = "1" ]; then
            if [ `ps -ef | grep "${SOLR_HOME}" | grep -v "grep" | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  solr already running." | tee -a ${LOGFILE}
            else
                if [ "${RUNSOLR}" = "1" ]; then
                    echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  solr start." | tee -a ${LOGFILE}
                    ${SOLR_HOME}/start_solr_linux.sh >>${LOGFILE} 2>&1
                    CHK_SOLRSTART
                fi
            fi
        fi

        ### derby start
        if [ -f "${DERBY_HOME}/bin/start.sh" -a "${RUNDERBY}" = "1" ]; then
            if [ `ps -ef | grep "derby.system.home=${DERBY_HOME}" | \
                    grep -v "grep" | wc -l` -ne 0 -a `netstat -an | \
                    grep ":${DERBY_PORT}" | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby already running." | tee -a ${LOGFILE}
            else
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby start." | tee -a ${LOGFILE}
                nohup ${DERBY_HOME}/bin/start.sh >>${LOGFILE} 2>&1 &
                CHK_DERBYSTART
            fi
        fi

        ### tomcat start
        if [ -f "${TOMCAT_HOME}/bin/startup.sh" -a "${RUNTOMCAT}" = "1" ]; then
            if [ `ps -ef | grep "${TOMCAT_HOME}" | grep -v "grep" | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  tomcat already running." | tee -a ${LOGFILE}
            else
                if [ "${RUNTOMCAT}" = "1" ]; then
                    echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  tomcat start." | tee -a ${LOGFILE}
                    ${TOMCAT_HOME}/bin/startup.sh >>${LOGFILE} 2>&1
                    CHK_TOMCATSTART
                fi
            fi
        fi

        ### caster start
        if [ -f "${CASTER_HOME}/bin/schbkr" -a "${RUNCASTER}" = "1" ]; then
            if [ `ps -ef | grep "${CASTER_HOME}" | grep -v "grep" | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  caster already running." | tee -a ${LOGFILE}
            else
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  caster start." | tee -a ${LOGFILE}
                nohup ${CASTER_HOME}/bin/schbkr >>${LOGFILE} 2>&1 &
                CHK_CASTERSTART
            fi
        fi

        ### eda start
        if [ -f "${EDA_START}" -a "${RUNEDA}" = "1" ]; then
            if [ `ps -ef | grep "${EDA_BIN}/eda" | grep -v "grep" | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  eda already running." | tee -a ${LOGFILE}
            else
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  eda start." | tee -a ${LOGFILE}
                ${EDA_START} -clear >>${LOGFILE} 2>&1
                ${EDA_START} -start >>${LOGFILE} 2>&1
                CHK_EDASTART
            fi
        fi

        CREATE_MAINPID
        ;;

    stop)
        ### solr stop
        if [ "${RUNSOLR}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  solr stop." | tee -a ${LOGFILE}
            ${SOLR_HOME}/stop_solr_linux.sh >>${LOGFILE} 2>&1
            CHK_SOLRSTOP
        fi

        ### tomcat stop
        if [ "${RUNTOMCAT}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  tomcat stop." | tee -a ${LOGFILE}
            ${TOMCAT_HOME}/bin/shutdown.sh >>${LOGFILE} 2>&1
            CHK_TOMCATSTOP
        fi

        ### caster stop
        if [ -f "${CASTER_HOME}/bin/stopit" -a "${RUNCASTER}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  caster stop." | tee -a ${LOGFILE}
            ${CASTER_HOME}/bin/stopit >>${LOGFILE} 2>&1
            CHK_CASTERSTOP
        fi

        ### derby stop
        if [ -f "${DERBY_HOME}/bin/stop.sh" -a "${RUNDERBY}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby stop." | tee -a ${LOGFILE}
            ${IBI_HOME}/derby/bin/stop.sh >>${LOGFILE} 2>&1
            CHK_DERBYSTOP
        fi

        ### eda stop
        if [ -f "${EDA_START}" -a "${RUNEDA}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  eda stop." | tee -a ${LOGFILE}
            ${EDA_START} -killall >>${LOGFILE} 2>&1
            ${EDA_START} -stop >>${LOGFILE} 2>&1
            CHK_EDASTOP
            ${EDA_START} -clear >>${LOGFILE} 2>&1
        fi

        TERM_MAINPID
        ;;

    restart)
        ### solr stop
        if [ "${RUNSOLR}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  solr stop." | tee -a ${LOGFILE}
            ${SOLR_HOME}/stop_solr_linux.sh >>${LOGFILE} 2>&1
            CHK_SOLRSTOP
        fi

        ### tomcat stop
        if [ "${RUNTOMCAT}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  tomcat stop." | tee -a ${LOGFILE}
            ${TOMCAT_HOME}/bin/shutdown.sh >>${LOGFILE} 2>&1
            CHK_TOMCATSTOP
        fi

        ### caster stop
        if [ -f "${CASTER_HOME}/bin/stopit" -a "${RUNCASTER}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  caster stop." | tee -a ${LOGFILE}
            ${CASTER_HOME}/bin/stopit >>${LOGFILE} 2>&1
            CHK_CASTERSTOP
        fi

        ### derby stop
        if [ -f "${DERBY_HOME}/bin/stop.sh" -a "${RUNDERBY}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby stop." | tee -a ${LOGFILE}
            ${DERBY_HOME}/bin/stop.sh >>${LOGFILE} 2>&1
            CHK_DERBYSTOP
        fi

        ### eda stop
        if [ -f "${EDA_START}" -a "${RUNEDA}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  eda stop." | tee -a ${LOGFILE}
            ${EDA_START} -killall >>${LOGFILE} 2>&1
            ${EDA_START} -stop >>${LOGFILE} 2>&1
            CHK_EDASTOP
            ${EDA_START} -clear >>${LOGFILE} 2>&1
            CHK_EDASTOP
        fi

        TERM_MAINPID
        sleep 5

        ### solr start
        if [ "${RUNSOLR}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  solr start." | tee -a ${LOGFILE}
            ${SOLR_HOME}/start_solr_linux.sh >>${LOGFILE} 2>&1
            CHK_SOLRSTART
        fi

        ### derby start
        if [ -f "${DERBY_HOME}/bin/start.sh" -a "${RUNDERBY} " = "1 " ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  derby start." | tee -a ${LOGFILE}
            nohup ${DERBY_HOME}/bin/start.sh >>${LOGFILE} 2>&1 &
            CHK_DERBYSTART
        fi

        ### tomcat start
        if [ "${RUNTOMCAT}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  tomcat start." | tee -a ${LOGFILE}
            ${TOMCAT_HOME}/bin/startup.sh >>${LOGFILE} 2>&1
            CHK_TOMCATSTART
        fi

        ### caster start
        if [ -f "${CASTER_HOME}/bin/schbkr" -a "${RUNCASTER}" = "1" ]; then
            if [ `ps -ef | grep "${CASTER_HOME}" | grep -v "grep" | wc -l` -ne 0 ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  caster already running." \
                        | tee -a ${LOGFILE}
            else
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  caster start." \
                        | tee -a ${LOGFILE}
                nohup ${CASTER_HOME}/bin/schbkr >>${LOGFILE} 2>&1 &
                CHK_CASTERSTART
            fi
        fi
        ### eda start
        if [ -f "${EDA_START}" -a "${RUNEDA}" = "1" ]; then
            echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  eda start." | tee -a ${LOGFILE}
            ${EDA_START} -start >>${LOGFILE} 2>&1
            CHK_EDASTART
        fi

        CREATE_MAINPID
        ;;

    status)
        ### derby status
        if [ -f "${DERBY_HOME}/bin/start.sh" -a "${RUNDERBY}" = "1" ]; then
            echo "[derby]" | tee -a ${LOGFILE}
            PID=`ps -ef | grep "derby.system.home=${DERBY_HOME}" | \
                    grep -v "grep" | awk '{print $2}' | tr "\n" " "`
            if [ -z "${PID}" ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  NotRunning" | tee -a ${LOGFILE}
                RTN=1
            else
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  Running ${PID}" | tee -a ${LOGFILE}
            fi
        fi

        ### eda status
        if [ -f "${EDA_START}" -a "${RUNEDA}" = "1" ]; then
            echo "[eda]" | tee -a ${LOGFILE}
            ${EDA_START} -status | tee -a ${LOGFILE}
            tail -1 ${LOGFILE} | grep "NotRunning" >/dev/null 2>&1
            test ${?} -eq 0 && RTN=1
        fi

        ### tomcat status
        if [ "${RUNTOMCAT}" = "1" ]; then
            echo "[tomcat]" | tee -a ${LOGFILE}
            PID=`ps -ef | grep "${TOMCAT_HOME}" | grep -v "grep" | awk '{print $2}' | tr "\n" " "`
            if [ -z "${PID}" ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  NotRunning" | tee -a ${LOGFILE}
                RTN=1
            else
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  Running ${PID}" | tee -a ${LOGFILE}
            fi
        fi

        ### caster status
        if [ -f "${CASTER_HOME}/bin/schbkr" -a "${RUNCASTER}" = "1" ]; then
            echo "[caster]" | tee -a ${LOGFILE}
            PID=`ps -ef | egrep "${CASTER_HOME}/bin/schbkr|-Dreportcaster.home=${CASTER_HOME}" | \
                    grep -v "grep" | awk '{print $2}' | tr "\n" " "`
            if [ -z "${PID}" ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  NotRunning" | tee -a ${LOGFILE}
                RTN=1
            else
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  Running ${PID}" | tee -a ${LOGFILE}
            fi
        fi

        ### solr status
        if [ "${RUNSOLR}" = "1" ]; then
            echo "[solr]" | tee -a ${LOGFILE}
            PID=`ps -ef | grep "${SOLR_HOME}" | grep -v "grep" | awk '{print $2}' | tr "\n" " "`
            if [ -z "${PID}" ]; then
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  NotRunning" | tee -a ${LOGFILE}
                RTN=1
            else
                echo "`date "+%m/%d/%Y %H:%M:%S.%3N"`  Running ${PID}" | tee -a ${LOGFILE}
            fi
        fi

        ;;

    *)
        echo $"Usage: $0 {start|stop|restart|status} [{derby|eda|tomcat|caster|solr}]" | tee -a ${LOGFILE}
        RTN=1
        ;;

esac

exit ${RTN}

